searchData={"items":[{"type":"module","title":"SimpleForm","doc":"`SimpleForm` provides a simple representation and manipulation of structured elements, \nsimilar to HTML or XML, using Elixir tuples and lists.","ref":"SimpleForm.html"},{"type":"module","title":"Overview - SimpleForm","doc":"A `SimpleForm.element()` is represented as:\n\n    {tag_name, attributes, content}\n\nWhere:\n- `tag_name` is a string representing the name of the element.\n- `attributes` is a list of key-value tuples defining element attributes.\n- `content` is a list containing strings (text content) or nested elements.","ref":"SimpleForm.html#module-overview"},{"type":"type","title":"SimpleForm.attribute/0","doc":"","ref":"SimpleForm.html#t:attribute/0"},{"type":"function","title":"SimpleForm.attribute?/1","doc":"Checks if value is an attribute.","ref":"SimpleForm.html#attribute?/1"},{"type":"function","title":"Examples - SimpleForm.attribute?/1","doc":"iex> SimpleForm.attribute?(true)\n    false\n    iex> SimpleForm.attribute?({\"p\", [{\"class\", \"intro\"}], [{\"strong\", [], [\"Hello\"]}, \" world!\"]})\n    false\n    iex> SimpleForm.attribute?({\"class\", \"strong\"})\n    true\n    iex> SimpleForm.attribute?(\"Hello World!\")\n    false","ref":"SimpleForm.html#attribute?/1-examples"},{"type":"type","title":"SimpleForm.content/0","doc":"","ref":"SimpleForm.html#t:content/0"},{"type":"function","title":"SimpleForm.content?/1","doc":"Checks if value is content.","ref":"SimpleForm.html#content?/1"},{"type":"function","title":"Examples - SimpleForm.content?/1","doc":"iex> SimpleForm.content?(true)\n    false\n    iex> SimpleForm.content?({\"p\", [{\"class\", \"intro\"}], [{\"strong\", [], [\"Hello\"]}, \" world!\"]})\n    true\n    iex> SimpleForm.content?({\"class\", \"strong\"})\n    false\n    iex> SimpleForm.content?(\"Hello World!\")\n    true","ref":"SimpleForm.html#content?/1-examples"},{"type":"type","title":"SimpleForm.element/0","doc":"","ref":"SimpleForm.html#t:element/0"},{"type":"function","title":"SimpleForm.element?/1","doc":"Checks if value is an element.","ref":"SimpleForm.html#element?/1"},{"type":"function","title":"Examples - SimpleForm.element?/1","doc":"iex> SimpleForm.element?(true)\n    false\n    iex> SimpleForm.element?({\"p\", [{\"class\", \"intro\"}], [{\"strong\", [], [\"Hello\"]}, \" world!\"]})\n    true\n    iex> SimpleForm.element?({\"class\", \"strong\"})\n    false\n    iex> SimpleForm.element?(\"Hello World!\")\n    false","ref":"SimpleForm.html#element?/1-examples"},{"type":"type","title":"SimpleForm.tag_name/0","doc":"","ref":"SimpleForm.html#t:tag_name/0"},{"type":"module","title":"SimpleForm.Attrs","doc":"`SimpleForm.Attrs` implements functions for manipulating SimpleForm attributes,\nsuch as getting a specific attribute from a Simpleform element or list of SimpleForm attributes.","ref":"SimpleForm.Attrs.html"},{"type":"function","title":"SimpleForm.Attrs.get/3","doc":"Get an attribute from a SimpleForm element or its list of attributes.","ref":"SimpleForm.Attrs.html#get/3"},{"type":"function","title":"Examples - SimpleForm.Attrs.get/3","doc":"iex> SimpleForm.Attrs.get({\"w:p\", [{\"a\", 123}, {\"b\", 6}], []}, \"a\")\n    {\"a\", 123}\n    iex> SimpleForm.Attrs.get([{\"a\", 123}, {\"b\", 6}], \"b\")\n    {\"b\", 6}\n    iex> SimpleForm.Attrs.get([{\"a\", 123}, {\"b\", 6}], \"c\")\n    nil\n    iex> SimpleForm.Attrs.get([{\"a\", 123}, {\"b\", 6}], \"c\", \"default\")\n    \"default\"\n    iex> SimpleForm.Attrs.get(nil, \"a\")\n    nil\n    iex> SimpleForm.Attrs.get(nil, \"a\", \"default\")\n    \"default\"","ref":"SimpleForm.Attrs.html#get/3-examples"},{"type":"function","title":"SimpleForm.Attrs.get_many/2","doc":"Get multiple attributes from a SimpleForm element or its list of attributes.\nThe order and placement of the attributes in the list is preserved w.r.t. the given keys.\n\nThis function is more performant than calling `get/3` multiple times,\nas it only iterates over `elements` once.","ref":"SimpleForm.Attrs.html#get_many/2"},{"type":"function","title":"Examples - SimpleForm.Attrs.get_many/2","doc":"iex> SimpleForm.Attrs.get_many({\"w:p\", [{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], []}, [\"a\", \"b\", \"c\"])\n    [{\"a\", 123}, {\"b\", 6}, {\"c\", 42}]\n    iex> SimpleForm.Attrs.get_many([{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], [\"a\", \"c\"])\n    [{\"a\", 123}, {\"c\", 42}]\n    iex> SimpleForm.Attrs.get_many([{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], [\"a\", \"d\", \"c\"])\n    [{\"a\", 123}, nil, {\"c\", 42}]\n    iex> SimpleForm.Attrs.get_many([{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], [\"d\", \"e\"])\n    [nil, nil]","ref":"SimpleForm.Attrs.html#get_many/2-examples"},{"type":"function","title":"SimpleForm.Attrs.get_many_value/2","doc":"Get multiple attribute values from a SimpleForm element or its list of attributes.\nThe order and placement of the attribute value in the list is preserved w.r.t. the given keys.\n\nThis function is more performant than calling `get_value/3` multiple times,\nas it only iterates over `elements` once.","ref":"SimpleForm.Attrs.html#get_many_value/2"},{"type":"function","title":"Examples - SimpleForm.Attrs.get_many_value/2","doc":"iex> SimpleForm.Attrs.get_many_value({\"w:p\", [{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], []}, [\"a\", \"b\", \"c\"])\n    [123, 6, 42]\n    iex> SimpleForm.Attrs.get_many_value([{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], [\"a\", \"c\"])\n    [123, 42]\n    iex> SimpleForm.Attrs.get_many_value([{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], [\"a\", \"d\", \"c\"])\n    [123, nil, 42]\n    iex> SimpleForm.Attrs.get_many_value([{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], [\"d\", \"e\"])\n    [nil, nil]","ref":"SimpleForm.Attrs.html#get_many_value/2-examples"},{"type":"function","title":"SimpleForm.Attrs.get_value/3","doc":"Get the value of an attribute from a SimpleForm element or its list of attributes.","ref":"SimpleForm.Attrs.html#get_value/3"},{"type":"function","title":"Examples - SimpleForm.Attrs.get_value/3","doc":"iex> SimpleForm.Attrs.get_value({\"w:p\", [{\"a\", 123}, {\"b\", 6}], []}, \"a\")\n    123\n    iex> SimpleForm.Attrs.get_value([{\"a\", 123}, {\"b\", 6}], \"b\")\n    6\n    iex> SimpleForm.Attrs.get_value([{\"a\", 123}, {\"b\", 6}], \"c\")\n    nil\n    iex> SimpleForm.Attrs.get_value([{\"a\", 123}, {\"b\", 6}], \"c\", \"default\")\n    \"default\"\n    iex> SimpleForm.Attrs.get_value(nil, \"a\")\n    nil\n    iex> SimpleForm.Attrs.get_value(nil, \"a\", \"default\")\n    \"default\"","ref":"SimpleForm.Attrs.html#get_value/3-examples"},{"type":"function","title":"SimpleForm.Attrs.key/1","doc":"Get the key of an attribute.","ref":"SimpleForm.Attrs.html#key/1"},{"type":"function","title":"Examples - SimpleForm.Attrs.key/1","doc":"iex> SimpleForm.Attrs.key({\"a\", 123})\n    \"a\"\n    iex> SimpleForm.Attrs.key(nil)\n    nil","ref":"SimpleForm.Attrs.html#key/1-examples"},{"type":"function","title":"SimpleForm.Attrs.value/1","doc":"Get the value of an attribute.","ref":"SimpleForm.Attrs.html#value/1"},{"type":"function","title":"Examples - SimpleForm.Attrs.value/1","doc":"iex> SimpleForm.Attrs.value({\"a\", 123})\n    123\n    iex> SimpleForm.Attrs.value(nil)\n    nil","ref":"SimpleForm.Attrs.html#value/1-examples"},{"type":"module","title":"SimpleForm.Element","doc":"SimpleForm.Element implements functions for manipulating SimpleForm elements,\nsuch as finding one by name in a list of elements or in the children of another element.","ref":"SimpleForm.Element.html"},{"type":"function","title":"SimpleForm.Element.attrs/1","doc":"Get the attributes of an element.","ref":"SimpleForm.Element.html#attrs/1"},{"type":"function","title":"Examples - SimpleForm.Element.attrs/1","doc":"iex> SimpleForm.Element.attrs(nil)\n    nil\n    iex> SimpleForm.Element.attrs({\"w:p\", [], [\"some text\"]})\n    []\n    iex> SimpleForm.Element.attrs({\"w:p\", [{\"id\", \"1\"}], [\"some text\"]})\n    [{\"id\", \"1\"}]","ref":"SimpleForm.Element.html#attrs/1-examples"},{"type":"function","title":"SimpleForm.Element.children/1","doc":"Get the children of an element.","ref":"SimpleForm.Element.html#children/1"},{"type":"function","title":"Examples - SimpleForm.Element.children/1","doc":"iex> SimpleForm.Element.children(nil)\n    nil\n    iex> SimpleForm.Element.children({\"w:p\", [], []})\n    []\n    iex> SimpleForm.Element.children({\"w:p\", [], [\"some text\"]})\n    [\"some text\"]\n    iex> SimpleForm.Element.children({\"w:p\", [{\"id\", \"1\"}], [\"some text\", \"more text\"]})\n    [\"some text\", \"more text\"]","ref":"SimpleForm.Element.html#children/1-examples"},{"type":"function","title":"SimpleForm.Element.find_by_name/4","doc":"Find an element by name in a list of elements.","ref":"SimpleForm.Element.html#find_by_name/4"},{"type":"function","title":"Options - SimpleForm.Element.find_by_name/4","doc":"* `recursive` (boolean): If true, the function will perform a recursive, depth-first search through the children of each element in the list.","ref":"SimpleForm.Element.html#find_by_name/4-options"},{"type":"function","title":"Examples - SimpleForm.Element.find_by_name/4","doc":"By default, `SimpleForm.Element.find_by_name/4` only searches the list's elements.\n\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], []}, {\"w:tbl\", [], []}], \"w:tbl\")\n    {\"w:tbl\", [], []}\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], []}, {\"w:tbl\", [], []}], \"w:sdt\")\n    nil\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], []}, {\"w:tbl\", [], []}], \"w:sdt\", {\"w:sdt\", [], []})\n    {\"w:sdt\", [], []}\n\nFor a recursive, depth-first search through the children of each element in the list, set the `recursive` option to `true`.\n\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}], \"w:r\", nil, recursive: true)\n    {\"w:r\", [], [\"some text\"]}\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}], \"w:sdt\", nil, recursive: true)\n    nil\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], [{\"w:r\", [], [\"some text\"]}, \"  \", {\"w:sdt\", [], []}]}], \"w:sdt\", nil, recursive: true)\n    {\"w:sdt\", [], []}\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], [{\"w:r\", [], [\"first text\"]}]}, \"  \", {\"w:p\", [], [{\"w:r\", [], [\"second text\"]}]}], \"w:r\", nil, recursive: true)\n    {\"w:r\", [], [\"first text\"]}\n\nNote: the option `recursive: true` requires setting a default value explicitly, otherwise this option is assumed as the default value.\n\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}], \"w:r\", recursive: true)\n    [recursive: true]\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}], \"w:r\", recursive: false)\n    [recursive: false]","ref":"SimpleForm.Element.html#find_by_name/4-examples"},{"type":"function","title":"SimpleForm.Element.find_many_by_name/2","doc":"Find multiple elements by their names in a list of elements.\nThe order and placement of the elements in the list is preserved w.r.t. the given names.\n\nThis function is more performant than calling `find_by_name/3` multiple times,\nas it only iterates over `elements` once.","ref":"SimpleForm.Element.html#find_many_by_name/2"},{"type":"function","title":"Examples - SimpleForm.Element.find_many_by_name/2","doc":"iex> elements = [{\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}, {\"w:tbl\", [], []}]\n    iex> SimpleForm.Element.find_many_by_name(elements, [\"w:p\"])\n    [{\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}]\n    iex> SimpleForm.Element.find_many_by_name(elements, [\"w:r\"])\n    [nil]\n    iex> SimpleForm.Element.find_many_by_name(elements, [\"w:tbl\", \"w:p\"])\n    [{\"w:tbl\", [], []}, {\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}]\n    iex> SimpleForm.Element.find_many_by_name(elements, [\"w:tbl\", \"w:r\"])\n    [{\"w:tbl\", [], []}, nil]\n    iex> SimpleForm.Element.find_many_by_name(elements, [\"w:sdt\", \"w:p\"])\n    [nil, {\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}]","ref":"SimpleForm.Element.html#find_many_by_name/2-examples"},{"type":"function","title":"SimpleForm.Element.find_recursive/2","doc":"Recursively find the first element to match the given predicate, or return the given default value.\n\nThis function performs a depth-first search through the children of an element or list of elements,\nand returns the first element for which the predicate returns true.","ref":"SimpleForm.Element.html#find_recursive/2"},{"type":"function","title":"Examples - SimpleForm.Element.find_recursive/2","doc":"iex> SimpleForm.Element.find_recursive(\n    ...>   [{\"w:p\", [], []}, {\"w:r\", [], [\"some text\"]}],\n    ...>   fn element -> element |> SimpleForm.Element.name() === \"w:r\" end\n    ...> )\n    {\"w:r\", [], [\"some text\"]}\n    iex> SimpleForm.Element.find_recursive(\n    ...>   [{\"w:p\", [], [{\"w:r\", [{\"id\", \"1\"}], [\"text\"]}]}, {\"w:r\", [{\"id\", \"2\"}], [\"text\"]}],\n    ...>   fn element -> element |> SimpleForm.Element.name() === \"w:r\" end\n    ...> )\n    {\"w:r\", [{\"id\", \"1\"}], [\"text\"]}\n    iex> SimpleForm.Element.find_recursive([], fn _ -> true end)\n    nil\n    iex> SimpleForm.Element.find_recursive([], fn _ -> true end, \"test\")\n    \"test\"\n    iex> SimpleForm.Element.find_recursive([{\"w:p\", [], [\"text\"]}], fn _ -> false end)\n    nil\n    iex> SimpleForm.Element.find_recursive([{\"w:p\", [], [\"text\"]}], fn _ -> false end, \"default\")\n    \"default\"","ref":"SimpleForm.Element.html#find_recursive/2-examples"},{"type":"function","title":"SimpleForm.Element.find_recursive/3","doc":"","ref":"SimpleForm.Element.html#find_recursive/3"},{"type":"function","title":"SimpleForm.Element.name/1","doc":"Get the name of an element.","ref":"SimpleForm.Element.html#name/1"},{"type":"function","title":"Examples - SimpleForm.Element.name/1","doc":"iex> SimpleForm.Element.name({\"w:p\", [], []})\n    \"w:p\"\n    iex> SimpleForm.Element.name(nil)\n    nil","ref":"SimpleForm.Element.html#name/1-examples"},{"type":"function","title":"SimpleForm.Element.text/1","doc":"Recursively get the text content of an element or list of elements.","ref":"SimpleForm.Element.html#text/1"},{"type":"function","title":"Examples - SimpleForm.Element.text/1","doc":"iex> SimpleForm.Element.text(nil)\n    nil\n    iex> SimpleForm.Element.text(\"some text\")\n    \"some text\"\n    iex> SimpleForm.Element.text({\"w:p\", [], []})\n    \"\"\n    iex> SimpleForm.Element.text([{\"w:p\", [], []}, {\"w:tbl\", [], []}])\n    \"\"\n    iex> SimpleForm.Element.text({\"w:p\", [], [\"some text\"]})\n    \"some text\"\n    iex> SimpleForm.Element.text([{\"w:p\", [], [\"some text\", \" other text.\"]}, {\"w:tbl\", [], [\"more text\"]}, {\"w:tbl\", [], []}])\n    \"some text other text.more text\"\n    iex> SimpleForm.Element.text([{\"w:p\", [], [\"some text\", \" other text.\", \" \"]}, {\"w:tbl\", [], [\"more text\"]}, {\"w:tbl\", [], []}])\n    \"some text other text. more text\"","ref":"SimpleForm.Element.html#text/1-examples"},{"type":"extras","title":"SimpleForm","doc":"# SimpleForm\n\nSimpleForm provides helper functions for working with parsed HTML and XML content, particularly when using [Saxy](https://hexdocs.pm/saxy/) (an XML parser) in Elixir projects. It simplifies data extraction, transformation, and manipulation by structuring parsed data in a consistent, tuple-based format, making traversal and modification more intuitive.\n\nThe term SimpleForm [originates from xmerl](https://www.erlang.org/docs/20/man/xmerl.html).\n\nWhile technically this library could work with datastructures from xmerl and Floki, the focus on Saxy specifically.","ref":"readme.html"},{"type":"extras","title":"Features - SimpleForm","doc":"- Utility functions for extracting and transforming parsed SimpleForm data\n- Seamless integration with Saxy's simple form representation\n- Simplified traversal of document trees and structured form data extraction\n- Reduces boilerplate code when processing structured SimpleForm content","ref":"readme.html#features"},{"type":"extras","title":"Installation - SimpleForm","doc":"Add `simple_form` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:simple_form, \"~> 1.0.0\"}\n  ]\nend\n```\n\nThen, fetch dependencies:\n\n```sh\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - SimpleForm","doc":"Detailed documentation is available at [HexDocs](https://hexdocs.pm/simple_form).","ref":"readme.html#documentation"},{"type":"extras","title":"License - SimpleForm","doc":"This project is licensed under the [EUPL-1.2 License](https://joinup.ec.europa.eu/software/page/eupl).","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [1.0.5](https://gitlab.com/toegang-voor-iedereen/backend/lib/simple_form/compare/1.0.4...1.0.5) (2025-02-05)","ref":"changelog.html"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Improve [@spec](https://gitlab.com/spec)'s for SimpleForm ([4f724d8](https://gitlab.com/toegang-voor-iedereen/backend/lib/simple_form/commit/4f724d8fcc6403bab8fb9f01cb8fc52a5247ccaf))\n\nChangelog\n\n## [1.0.4](https://gitlab.com/toegang-voor-iedereen/backend/lib/simple_form/compare/1.0.3...1.0.4) (2025-02-05)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* hopefully now finally fix documentation generation ([0aed8f3](https://gitlab.com/toegang-voor-iedereen/backend/lib/simple_form/commit/0aed8f389bc0690f416840723c6d545fe34e718c))\n\n## [1.0.3](https://gitlab.com/toegang-voor-iedereen/backend/lib/simple_form/compare/1.0.2...1.0.3) (2025-02-05)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **NLD-625:** module packaging improvement ([0cdcab6](https://gitlab.com/toegang-voor-iedereen/backend/lib/simple_form/commit/0cdcab643c01599c99e4d0f14bb2da5765538f98))\n\n## [1.0.2](https://gitlab.com/toegang-voor-iedereen/backend/lib/simple_form/compare/1.0.1...1.0.2) (2025-02-05)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **NLD-625:** improve specs and docs ([44558c1](https://gitlab.com/toegang-voor-iedereen/backend/lib/simple_form/commit/44558c16a5667b376ef108fd7cab371e8ef12fff))\n\n## [1.0.1](https://gitlab.com/toegang-voor-iedereen/backend/lib/simple_form/compare/1.0.0...1.0.1) (2025-02-05)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **NLD-625:** Fix Module recognition ([9ebc5c1](https://gitlab.com/toegang-voor-iedereen/backend/lib/simple_form/commit/9ebc5c1550a854f9127406d19944f58bc201c1aa))","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"1.0.0 (2025-02-05) - Changelog","doc":"","ref":"changelog.html#1-0-0-2025-02-05"},{"type":"extras","title":"Features - Changelog","doc":"* **NLD-625:** initial commit ([7e83588](https://gitlab.com/toegang-voor-iedereen/backend/lib/simple_form/commit/7e83588bded1592cff150200fdc9d0a35fcb39cd))","ref":"changelog.html#features"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}